function varargout = gui4(varargin)
% GUI4 M-file for gui4.fig
%      GUI4, by itself, creates a new GUI4 or raises the existing
%      singleton*.
%
%      H = GUI4 returns the handle to a new GUI4 or the handle to
%      the existing singleton*.
%
%      GUI4('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in GUI4.M with the given input arguments.
%
%      GUI4('Property','Value',...) creates a new GUI4 or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before gui4_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to gui4_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Copyright 2002-2003 The MathWorks, Inc.

% Edit the above text to modify the response to help gui4

% Last Modified by GUIDE v2.5 17-Sep-2006 18:57:18

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @gui4_OpeningFcn, ...
                   'gui_OutputFcn',  @gui4_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before gui4 is made visible.
function gui4_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to gui4 (see VARARGIN)

% Choose default command line output for gui4
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes gui4 wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = gui4_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --------------------------------------------------------------------
function Pick_Callback(hObject, eventdata, handles)
% hObject    handle to Pick (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
    % x-y-Ausschnitt fest definieren
    axis( [0 10 0 10] );  

    % Einen Punkt mit der Maus auswählen und
    % die x-Koordinate des Punktes an x1, 
    % die y-Koordinate an y1 zurückgeben
    [x1,y1] = ginput(1);
    
    % Koordinaten (x1,y1) des Punktes in die 
    % Static-Text-Felder text1 und text2 schreiben
    set( handles.text1, 'String', x1 );
    set( handles.text2, 'String', y1 );
    
    % Zweiten Punkt mit der Maus auswählen und
    % die x-Koordinate an x2, y-Koordinate an y2
    [x2,y2] = ginput(1);
    
    % Arrays zum Plotten belegen
    x = [x1, x2];
    y = [y1, y2];
 
    % Plot-Ausgabe der Linie
    plot(x,y);
    % x-y-Ausschnitt fest definieren
    axis( [0 10 0 10] );  




% --------------------------------------------------------------------
function axes_context_menu_Callback(hObject, eventdata, handles)
% hObject    handle to axes_context_menu (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)




% --- Executes on key press over figure1 with no controls selected.
function figure1_KeyPressFcn(hObject, eventdata, handles)
% hObject    handle to figure1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

   % Zeichen zur Taste in Variable c speichern 
   c = get( hObject, 'CurrentCharacter' ); 
   
   % Starte das Picken, falls Zeichen p gedrückt wurde 
   if( c == 'p' ) 
      axis( [0 10 0 10] ); 
      [x1,y1] = ginput(1); 
      [x2,y2] = ginput(1); 
      
      x = [x1, x2]; 
      y = [y1, y2]; 
      
      plot(x,y); 
      axis( [0 10 0 10] ); 
   end
